==> apache-hop-2.8.0-src.tar.gz: apache-hop-2.8.0/plugins/transforms/filemetadata/src/test/java/org/apache/hop/pipeline/transforms/filemetadata/FileMetadataMetaTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.hop.pipeline.transforms.filemetadata;

import org.apache.hop.pipeline.transform.TransformSerializationTestUtil;
import org.junit.Assert;
import org.junit.Test;

public class FileMetadataMetaTest {

  @Test
  public void testSerialization() throws Exception {
    FileMetadataMeta meta =
        TransformSerializationTestUtil.testSerialization(
            "/file-metadata-transform.xml", FileMetadataMeta.class);
    Assert.assertNotNull(meta.getFileName());
    Assert.assertNotNull(meta.getLimitRows());
    Assert.assertNotNull(meta.getDefaultCharset());
    Assert.assertEquals(3, meta.getDelimiterCandidates().size());
    Assert.assertEquals(2, meta.getEnclosureCandidates().size());
  }
}

==> apache-hop-2.16.0-src.tar.gz: apache-hop-2.16.0/plugins/transforms/filemetadata/src/test/java/org/apache/hop/pipeline/transforms/filemetadata/FileMetadataMetaTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.hop.pipeline.transforms.filemetadata;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;

import org.apache.hop.pipeline.transform.TransformSerializationTestUtil;
import org.junit.jupiter.api.Test;

class FileMetadataMetaTest {

  @Test
  void testSerialization() throws Exception {
    FileMetadataMeta meta =
        TransformSerializationTestUtil.testSerialization(
            "/file-metadata-transform.xml", FileMetadataMeta.class);
    assertNotNull(meta.getFileName());
    assertNotNull(meta.getLimitRows());
    assertNotNull(meta.getDefaultCharset());
    assertEquals(3, meta.getDelimiterCandidates().size());
    assertEquals(2, meta.getEnclosureCandidates().size());
  }
}
